==> igniteui-react-core-16.15.1.tgz: package/esm2015/lib/DotNetCodeGeneratingComponentRendererModuleEmitter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { CodeGeneratingComponentRendererModuleEmitter } from "./CodeGeneratingComponentRendererModuleEmitter";
import { Dictionary$2 } from "./Dictionary$2";
import { List$1 } from "./List$1";
import { String_$type, markType } from "./type";
import { stringEndsWith } from "./string";
/**
 * @hidden
 */
export let DotNetCodeGeneratingComponentRendererModuleEmitter = /*@__PURE__*/ (() => {
    class DotNetCodeGeneratingComponentRendererModuleEmitter extends CodeGeneratingComponentRendererModuleEmitter {
        constructor(a, b, c) {
            super(b, c);
            this.o = 0;
            this.r = 0;
            this.p = false;
            this.q = new Dictionary$2(String_$type, List$1.$.specialize(String_$type), 0);
            this.o = a;
        }
        n() {
            super.n();
            this.r = 0;
        }
        get s() {
            switch (this.o) {
                case 0: return "Xam";
                case 4: return "Ultra";
            }
            return "";
        }
        k(a) {
            super.k(a);
            if (a == "withDescriptions") {
                this.p = true;
                return;
            }
            let b = "";
            let c = a.split('/');
            if (c.length == 1) {
                b = c[0];
            }
            else {
                b = c[1];
            }
            if (this.p) {
                if (this.r == 0) {
                    this.c.k("private ComponentRenderer _componentRenderer = null;");
                    this.c.k("public ComponentRenderer Renderer");
                    this.c.k("{");
                    this.c.h();
                    this.c.k("get");
                    this.c.k("{");
                    this.c.h();
                    this.c.k("if (this._componentRenderer == null)");
                    this.c.k("{");
                    this.c.h();
                    this.c.k("this._componentRenderer = new ComponentRenderer();");
                    this.c.k("var context = this._componentRenderer.Context;");
                }
                let d = b;
                if (stringEndsWith(d, "Module")) {
                    d = d.substr(0, d.length - ("Module").length);
                    d += "DescriptionModule";
                }
                this.c.k(d + ".Register(context);");
            }
            this.r++;
        }
        m() {
            super.m();
            this.g.addUsing("using Infragistics.Controls.Description;");
            if (this.p) {
                this.c.f();
                this.c.k("}");
                this.c.f();
                this.c.k("return this._componentRenderer;");
                this.c.k("}");
                this.c.f();
                this.c.k("}");
            }
        }
    }
    DotNetCodeGeneratingComponentRendererModuleEmitter.$t = /*@__PURE__*/ markType(DotNetCodeGeneratingComponentRendererModuleEmitter, 'DotNetCodeGeneratingComponentRendererModuleEmitter', CodeGeneratingComponentRendererModuleEmitter.$);
    return DotNetCodeGeneratingComponentRendererModuleEmitter;
})();

==> igniteui-react-core-16.16.0.tgz: package/esm2015/lib/DotNetCodeGeneratingComponentRendererModuleEmitter.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { CodeGeneratingComponentRendererModuleEmitter } from "./CodeGeneratingComponentRendererModuleEmitter";
import { Dictionary$2 } from "./Dictionary$2";
import { List$1 } from "./List$1";
import { String_$type, markType } from "./type";
import { stringEndsWith } from "./string";
/**
 * @hidden
 */
export let DotNetCodeGeneratingComponentRendererModuleEmitter = /*@__PURE__*/ (() => {
    class DotNetCodeGeneratingComponentRendererModuleEmitter extends CodeGeneratingComponentRendererModuleEmitter {
        constructor(a, b, c) {
            super(b, c);
            this.o = 0;
            this.r = 0;
            this.p = false;
            this.q = new Dictionary$2(String_$type, List$1.$.specialize(String_$type), 0);
            this.o = a;
        }
        get s() {
            return this.r;
        }
        n() {
            super.n();
            this.r = 0;
        }
        get t() {
            switch (this.o) {
                case 0: return "Xam";
                case 4: return "Ultra";
                case 5: return "Igb";
            }
            return "";
        }
        k(a) {
            super.k(a);
            if (a == "withDescriptions" && this.o != 5) {
                this.p = true;
                return;
            }
            let b = "";
            let c = a.split('/');
            if (c.length == 1) {
                b = c[0];
            }
            else {
                b = c[1];
            }
            if (this.p) {
                if (this.r == 0) {
                    this.c.k("private ComponentRenderer _componentRenderer = null;");
                    this.c.k("public ComponentRenderer Renderer");
                    this.c.k("{");
                    this.c.h();
                    this.c.k("get");
                    this.c.k("{");
                    this.c.h();
                    this.c.k("if (this._componentRenderer == null)");
                    this.c.k("{");
                    this.c.h();
                    this.c.k("this._componentRenderer = new ComponentRenderer();");
                    this.c.k("var context = this._componentRenderer.Context;");
                }
                let d = b;
                if (stringEndsWith(d, "Module")) {
                    d = d.substr(0, d.length - ("Module").length);
                    d += "DescriptionModule";
                }
                this.c.k(d + ".Register(context);");
            }
            this.r++;
        }
        m() {
            super.m();
            if (this.p) {
                this.g.addUsing("using Infragistics.Controls.Description;");
                this.c.f();
                this.c.k("}");
                this.c.f();
                this.c.k("return this._componentRenderer;");
                this.c.k("}");
                this.c.f();
                this.c.k("}");
            }
        }
    }
    DotNetCodeGeneratingComponentRendererModuleEmitter.$t = /*@__PURE__*/ markType(DotNetCodeGeneratingComponentRendererModuleEmitter, 'DotNetCodeGeneratingComponentRendererModuleEmitter', CodeGeneratingComponentRendererModuleEmitter.$);
    return DotNetCodeGeneratingComponentRendererModuleEmitter;
})();
